@@ -101,6 +101,7 @@ def plot_wcs_data(
     trim: tuple = (None, None),
     vmin: Optional[float] = None,
     vmax: Optional[float] = None,
+    overlay_data: Optional[np.ndarray] = None,
     overlay_hdu: Optional[list] = None,
     overlay_pmin: Optional[float] = None,
     overlay_channels: Optional[list] = None,
@@ -120,6 +121,8 @@ def plot_wcs_data(
     plot_beam: bool = False,
     plot_overlay_beam: bool = False,
     show: bool = True,
+    num_levels: Optional[int] = None,
+    interpolation: str = "none",
     **kwargs,
 ) -> None:
     """
@@ -142,6 +145,7 @@ def plot_wcs_data(
     # override default colormaps
     overlay_cmap = kwargs.get("overlay_cmap", categorical_cmap)
     overlay_color_list = kwargs.get("overlay_color_list", colors)
+    overlay_alpha = kwargs.get("overlay_alpha", 1.0)
 
     if fits_path is not None:
         hdu = fits.open(fits_path)
@@ -179,6 +183,8 @@ def plot_wcs_data(
             channel=channel,
             subtract_channels=subtract_channels,
         )
+    else:
+        plot_data *= scale_data
 
     if subtract_data is not None:
         plot_data = plot_data.copy()
@@ -189,9 +195,18 @@ def plot_wcs_data(
 
     # plot
     if log:
-        plt.imshow(plot_data, origin="lower", cmap=plot_cmap, vmin=vmin, vmax=vmax, norm=norm)
+        plt.imshow(
+            plot_data, origin="lower", cmap=plot_cmap, norm=norm, interpolation=interpolation
+        )
     else:
-        plt.imshow(plot_data, origin="lower", cmap=plot_cmap, vmin=vmin, vmax=vmax)
+        plt.imshow(
+            plot_data,
+            origin="lower",
+            cmap=plot_cmap,
+            vmin=vmin,
+            vmax=vmax,
+            interpolation=interpolation,
+        )
 
     cbar = plt.colorbar(fraction=0.045, pad=0.005)
     cbar.ax.set_ylabel(plot_units, rotation=270, fontsize=legend_font)
@@ -208,7 +223,8 @@ def plot_wcs_data(
         overlay_hdu[0].header["CRVAL2"] = 0.0
         overlay_wcs = WCS(overlay_hdu[0].header, naxis=2)
 
-        overlay_data = overlay_hdu[0].data.copy().squeeze()
+        if overlay_data is None:
+            overlay_data = overlay_hdu[0].data.copy().squeeze()
 
         # make sure we have a channel axis to iterate over (e.g. for continuum)
         if len(overlay_data.shape) == 2:
@@ -247,6 +263,8 @@ def plot_wcs_data(
                 this_overlay_data,
                 transform=ax.get_transform(overlay_wcs),
                 colors=overlay_cmap[i],
+                levels=num_levels,
+                alpha=overlay_alpha,
             )
 
     # set axis labels
@@ -354,7 +372,13 @@ def plot_polar_and_get_contour(
         warnings.simplefilter("ignore")
         im = ax.pcolormesh(phis, rs, data, cmap=plot_cmap)
     # extract the contour for the contour_value
-    contour = ax.contour(phis, rs, data, levels=[contour_value], colors="k")
+    contour = ax.contour(
+        phis,
+        rs,
+        data,
+        levels=[contour_value],
+        colors="k",
+    )
 
     ax.tick_params(pad=20)
 
@@ -444,7 +468,7 @@ def polar_plot(
     ps = kwargs.get("ps", s)
 
     mplrc("xtick", labelsize=tick_font)
-    mplrc("ytick", labelsize=ticks)
+    mplrc("ytick", labelsize=tick_font)
 
     _, ax = plt.subplots(figsize=figsize, subplot_kw={"projection": "polar"})
 
@@ -492,6 +516,8 @@ def basic_image_plot(
     show: bool = True,
     save_name: str = "plot.pdf",
     log: bool = False,
+    trimx: int = 0,
+    trimy: int = 0,
     **kwargs,
 ) -> None:
     """Plots a basic image"""
@@ -510,7 +536,7 @@ def basic_image_plot(
 
     # plot
     if log:
-        im = plt.imshow(data, origin="lower", cmap=plot_cmap, vmin=vmin, vmax=vmax, norm=norm)
+        im = plt.imshow(data, origin="lower", cmap=plot_cmap, norm=norm)
     else:
         im = plt.imshow(data, origin="lower", cmap=plot_cmap, vmin=vmin, vmax=vmax)
 
@@ -525,6 +551,11 @@ def basic_image_plot(
     plt.xticks(fontsize=tick_font)
     plt.yticks(fontsize=tick_font)
 
+    if trimx > 0:
+        plt.xlim(trimx, data.shape[1] - trimx)
+    if trimy > 0:
+        plt.ylim(trimy, data.shape[0] - trimy)
+
     if save:
         plt.savefig(save_name)
 
